Learn R Programming

Ryacas (version 0.3-1)

Ryacas-package: R interface to yacas computer algebra package

Description

Ryacas allows one to use the yacas computer algebra package entirely from within R. It takes an R expression, an R one line function or a yacas string and returns an R expression or a variety of other formats. It can be used for symbolic mathematics, exact arithmetic, ASCII pretty printing and R to TeX conversions. The main command is yacas and ?yacas provides some information on installation and startup.

Arguments

Details

The following are sources of information on "Ryacas":
DESCRIPTION file
library(help = Ryacas)
List of demo files
demo(package = "Ryacas")
Demo file
demo("Ryacas")
Demo
demo("Ryacas-PrettyPrinter")
Demo
demo("Ryacas-Function")
Demo
demo("Ryacas-Sym")
Demo
demo("Ryacas-Expr")
List Vignettes
vignette(package = "Ryacas")
Vignette
vignette("Ryacas")
This File
package?Ryacas
Help files
?yacas, ?yacasTranslations, ?yacmode, ?Sym
Help files - Windows
?yacasInstall
News
RShowDoc("NEWS", package = "Ryacas")
Acknowledgements
RShowDoc("THANKS", package = "Ryacas")
Wish List
RShowDoc("WISHLIST", package = "Ryacas")
Home page
http://code.google.com/p/ryacas/

Examples

Run this code
## Not run: 
# print(yacas(expression(integrate(1/x, x))))
# print(yacas("Integrate(x)1/x"))
# x <- Sym("x"); Integrate(1/x, x)
# acos(Sym("1/2"))
# ## End(Not run)

Run the code above in your browser using DataLab