Learn R Programming

Ryacas (version 0.3-1)

bodyAsExpression: Get body of function as an expression.

Description

Get body of function as an expression.

Usage

bodyAsExpression(x)

Arguments

x
An R function.

Value

An expression.

Details

This function is similar to the R body function except that function returns a call object whereas this one returns an expression usable in Ryacas calculations.

See Also

body

Examples

Run this code
## Not run: 
# 
# # construct an R function for the Burr probability density
# # function (PDF) given the Burr cumulative distribution function (CDF)
# BurrCDF <- function(x, c = 1, k = 1) 1-(1+x^c)^-k
# 
# # transfer CDF to yacas
# yacas(BurrCDF)
# 
# # create a template for the PDF from the CDF
# BurrPDF <- BurrCDF
# 
# # differentiate CDF and place resulting expression in body
# body(BurrPDF) <- yacas(expression(deriv(BurrCDF(x,c,k))))[[1]]
# 
# # test out PDF
# BurrPDF(1)
# 
# ## End(Not run)

Run the code above in your browser using DataLab